==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/AffineMatrix2D.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_
#define _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HDL_
#include "com/sun/star/geometry/AffineMatrix2D.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline AffineMatrix2D::AffineMatrix2D() SAL_THROW( () )
    : m00(0)
    , m01(0)
    , m02(0)
    , m10(0)
    , m11(0)
    , m12(0)
{
}

inline AffineMatrix2D::AffineMatrix2D(const double& m00_, const double& m01_, const double& m02_, const double& m10_, const double& m11_, const double& m12_) SAL_THROW( () )
    : m00(m00_)
    , m01(m01_)
    , m02(m02_)
    , m10(m10_)
    , m11(m11_)
    , m12(m12_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::AffineMatrix2D const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.AffineMatrix2D");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/geometry/AffineMatrix2D.hpp <==
#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_
#define _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HDL_
#include "com/sun/star/geometry/AffineMatrix2D.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace geometry {

inline AffineMatrix2D::AffineMatrix2D() SAL_THROW( () )
    : m00(0)
    , m01(0)
    , m02(0)
    , m10(0)
    , m11(0)
    , m12(0)
{
}

inline AffineMatrix2D::AffineMatrix2D(const double& m00_, const double& m01_, const double& m02_, const double& m10_, const double& m11_, const double& m12_) SAL_THROW( () )
    : m00(m00_)
    , m01(m01_)
    , m02(m02_)
    , m10(m10_)
    , m11(m11_)
    , m12(m12_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace geometry {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::geometry::AffineMatrix2D const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.geometry.AffineMatrix2D");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::geometry::AffineMatrix2D const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::geometry::AffineMatrix2D >::get();
}

#endif // _COM_SUN_STAR_GEOMETRY_AFFINEMATRIX2D_HPP_
